pub struct BlockData {
pub params: Vec<Param>,
pub succs: Vec<BlockCall>,
/* private fields */
}Expand description
One block: what arrives in it, what is in it, and where it goes.
Fields
params: Vec<Param>The values that arrive in it, which are the function’s arguments in the entry block.
succs: Vec<BlockCall>Where its terminator goes, in the order the terminator’s arms run.